function[Y_complete] = completeData(X,Y,alpha, beta, s2,c)
% Simulate the complete data given a sensoring level and the parameers of a
% linear regression.  It is assumed that the true values of all values
% observed at the sensoring value are above or at the sensoring value.
% 
%
% @param    X       : design matrix
% @param    Y       : observed output
% @param    alpha   : intercept of regression line
% @param    beta    : slope of regression line
% @param    s2      : variance of regression
% @param    c       : sensoring value
%
% @return   Y_complete : a draw from the complete data distribution 
%
% Copyright January, 2011, Columbia University, New York, NY. 
% All Rights Reserved 
%
% Permission to use, copy, modify, and distribute this software and its
% documentation for any purpose other than its incorporation into a commercial
% product is hereby granted without fee, provided that the above copyright
% notice appear in all copies and that both that copyright notice and this
% permission notice appear in supporting documentation, and that the name of
% Columbia University not be used in advertising or publicity pertaining to
% distribution of the software without specific, written prior permission. 
%
% COLUMBIA UNIVERSITY DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE
% , INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR ANY
% PARTICULAR PURPOSE. IN NO EVENT SHALL COLUMBIA UNIVERSITY BE LIABLE FOR 
% ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER
% RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF
% CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
% CONNECTION WITH THE USE.
%
% Author: Nichoas Bartlett bartlett@stat.columbia.edu

[rows cols] = size(X);

assert(cols == 1, 'the number of columns is assumed to be one but appears to be otherwise')
assert(length(Y) == rows)

% initialize the compete data matrix
Y_complete = zeros(size(Y));

s = sqrt(s2);

for i = 1:rows;
    if Y(i) < c
        Y_complete(i) = Y(i);
    else
        m = alpha + beta * X(i);
        
        % simulate the true Y value from the truncated Gaussian
        lowUnif = normcdf(c,m,s);
        r = unifrnd(lowUnif,1.0);
        Y_complete(i) = norminv(r,m,s);
    end
end