function[pi95,pi98,pi99,pi995] = predictionIntervals(posteriorSamples, ages, predictionsPerSample)
% Simulate draws from the posterior model to calculate prediction
% confidence intervals.  For each model drawn from the posterior, a
% specified number of predictions are made in order to calculate the
% prediction interval accurately.
%
% @param posteriorSamples     :   samples of the model drawn from the posterior
% @param ages                 :   values of the ages for which prediction interals are needed
% @param predictionsPerSample :   number of predictions drawn per model
% 
% @return pi95                :   .95  confidence interval
% @return pi98                :   .98  confidence interval
% @return pi99                :   .99  confidence interval
% @return pi995               :   .995 confidence interval
%
% Copyright January, 2011, Columbia University, New York, NY. 
% All Rights Reserved 
%
% Permission to use, copy, modify, and distribute this software and its
% documentation for any purpose other than its incorporation into a commercial
% product is hereby granted without fee, provided that the above copyright
% notice appear in all copies and that both that copyright notice and this
% permission notice appear in supporting documentation, and that the name of
% Columbia University not be used in advertising or publicity pertaining to
% distribution of the software without specific, written prior permission. 
%
% COLUMBIA UNIVERSITY DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE
% , INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR ANY
% PARTICULAR PURPOSE. IN NO EVENT SHALL COLUMBIA UNIVERSITY BE LIABLE FOR 
% ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER
% RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF
% CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
% CONNECTION WITH THE USE.
%
% Author: Nichoas Bartlett bartlett@stat.columbia.edu

rows = length(posteriorSamples);

predictions = zeros(rows * predictionsPerSample,91);

prediction = 1;
for row = 1 : rows
    m = posteriorSamples(row,1) + posteriorSamples(row,2)*ages;
    s = sqrt(posteriorSamples(row,3));
    for pred = 1 : predictionsPerSample
        predictions(prediction,:) = normrnd(m,s);
        prediction = prediction + 1;
    end
end

pi95 = zeros(2,91);
pi98 = zeros(2,91);
pi99 = zeros(2,91);
pi995 = zeros(2,91);

for i = 1 : 91
    pi95(:,i) = quantile(predictions(:,i),[.025,.975])';
    pi98(:,i) = quantile(predictions(:,i),[.01,.99])';    
    pi99(:,i) = quantile(predictions(:,i),[.005,.995])';
    pi995(:,i) = quantile(predictions(:,i),[.0025,.9975])';
end

