function[alpha, beta] = sampleAlphaBeta(X,Y_complete,s2)
% Sample the intercept and slope parameters of a Bayesian linear regression
% from the conditional posterior distribution.
%
% @param X            :   design matrix
% @param Y_complete   :   output of regression model
% @param s2           :   variance of regression model
% 
% @return alpha       :   intercept simulated from conditional posterior distribution
% @return beta        :   slope simulated from conditional posterior distribution
%
% Copyright January, 2011, Columbia University, New York, NY. 
% All Rights Reserved 
%
% Permission to use, copy, modify, and distribute this software and its
% documentation for any purpose other than its incorporation into a commercial
% product is hereby granted without fee, provided that the above copyright
% notice appear in all copies and that both that copyright notice and this
% permission notice appear in supporting documentation, and that the name of
% Columbia University not be used in advertising or publicity pertaining to
% distribution of the software without specific, written prior permission. 
%
% COLUMBIA UNIVERSITY DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE
% , INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR ANY
% PARTICULAR PURPOSE. IN NO EVENT SHALL COLUMBIA UNIVERSITY BE LIABLE FOR 
% ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER
% RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF
% CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
% CONNECTION WITH THE USE.
%
% Author: Nichoas Bartlett bartlett@stat.columbia.edu

% add a row of ones to the design matrix for the intercept component
X = [ones(length(X),1),X];

XtXinv = inv(X'*X);
sigma = s2 * XtXinv;

m = XtXinv*X'*Y_complete;
b = mvnrnd(m,sigma);

alpha = b(1);
beta = b(2);

