function[s2] = sampleSigma2(X,Y_complete,alpha, beta)
% Sample the variance parameter of a Bayesian linear regression conditional
% on the parameters of the mean line.
% @param X            :   design matrix
% @param Y_complete   :   observed output
% @param alpha        :   intercept of mean line
% @param beta         :   slope of mean line
% 
% @return s2          :   variance sampled from conditional posterior distribution
%
% Copyright January, 2011, Columbia University, New York, NY. 
% All Rights Reserved 
%
% Permission to use, copy, modify, and distribute this software and its
% documentation for any purpose other than its incorporation into a commercial
% product is hereby granted without fee, provided that the above copyright
% notice appear in all copies and that both that copyright notice and this
% permission notice appear in supporting documentation, and that the name of
% Columbia University not be used in advertising or publicity pertaining to
% distribution of the software without specific, written prior permission. 
%
% COLUMBIA UNIVERSITY DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE
% , INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR ANY
% PARTICULAR PURPOSE. IN NO EVENT SHALL COLUMBIA UNIVERSITY BE LIABLE FOR 
% ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER
% RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF
% CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
% CONNECTION WITH THE USE.
%
% Author: Nichoas Bartlett bartlett@stat.columbia.edu

% get the number of data points
n = length(X);

% get the residuals
r = Y_complete - alpha*ones(n,1) - beta * X; 

% get the sum of squared residuals
ss = r' * r;

% simulate the precision (inverse variance) from the conditional posterior
% distribution
s2Inv = gamrnd(n/2 + 2, 2/ss);

%set the variance to the inverse of the precision
s2 = 1/s2Inv;